@@ -41,7 +41,7 @@ A backup of the current config can be found at ~/myconfig.omp.json.bak.`,
 	Args: cobra.NoArgs,
 	Run: func(_ *cobra.Command, _ []string) {
 		configFile := config.Path(configFlag)
-		cfg := config.Load(configFile, shell.GENERIC, true)
+		cfg, _ := config.Load(configFile, shell.GENERIC, true)
 
 		flags := &runtime.Flags{
 			Config:  configFile,
