@@ -21,7 +21,7 @@ var (
 	force bool
 )
 
-// noticeCmd represents the get command
+// upgradeCmd represents the upgrade command
 var upgradeCmd = &cobra.Command{
 	Use:   "upgrade",
 	Short: "Upgrade when a new version is available.",
@@ -32,8 +32,7 @@ var upgradeCmd = &cobra.Command{
 
 		if debug {
 			startTime = time.Now()
-			log.Enable()
-			log.Debug("debug mode enabled")
+			log.Enable(plain)
 		}
 
 		supportedPlatforms := []string{
