@@ -146,11 +146,15 @@ func (segment *Segment) Execute(env runtime.Environment) {
 	}
 }
 
-func (segment *Segment) Render(index int) bool {
-	if !segment.Enabled {
+func (segment *Segment) Render(index int, force bool) bool {
+	if !segment.Enabled && !force {
 		return false
 	}
 
+	if force {
+		segment.Force = true
+	}
+
 	segment.writer.SetIndex(index)
 
 	text := segment.string()
@@ -230,8 +234,8 @@ func (segment *Segment) isToggled() bool {
 		return false
 	}
 
-	list := strings.Split(toggles, ",")
-	for _, toggle := range list {
+	list := strings.SplitSeq(toggles, ",")
+	for toggle := range list {
 		if SegmentType(toggle) == segment.Type || toggle == segment.Alias {
 			log.Debugf("segment toggled off: %s", segment.Name())
 			return true
