@@ -6,6 +6,7 @@ import (
 	"path"
 	"strings"
 
+	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/spf13/pflag"
 	"gopkg.in/yaml.v3"
 )
@@ -45,7 +46,7 @@ func (a *Argocd) Enabled() bool {
 	configPath := a.getConfigPath()
 	succeeded, err := a.parseConfig(configPath)
 	if err != nil {
-		a.env.Error(err)
+		log.Error(err)
 		return false
 	}
 	return succeeded
@@ -83,7 +84,7 @@ func (a *Argocd) parseConfig(file string) (bool, error) {
 	var data ArgocdConfig
 	err := yaml.Unmarshal([]byte(config), &data)
 	if err != nil {
-		a.env.Error(err)
+		log.Error(err)
 		return false, errors.New(argocdInvalidYaml)
 	}
 	a.Name = data.CurrentContext
