@@ -2,12 +2,10 @@ package segments
 
 import (
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 type Spotify struct {
-	props properties.Properties
-	env   runtime.Environment
+	base
 
 	MusicPlayer
 }
@@ -26,10 +24,13 @@ const (
 	PausedIcon properties.Property = "paused_icon"
 	// StoppedIcon indicates a song is stopped
 	StoppedIcon properties.Property = "stopped_icon"
+	// AdIcon indicates an advertisement is playing
+	AdIcon properties.Property = "ad_icon"
 
-	playing = "playing"
-	stopped = "stopped"
-	paused  = "paused"
+	playing     = "playing"
+	stopped     = "stopped"
+	paused      = "paused"
+	advertising = "advertising"
 )
 
 func (s *Spotify) Template() string {
@@ -47,8 +48,3 @@ func (s *Spotify) resolveIcon() {
 		s.Icon = s.props.GetString(PlayingIcon, "\uE602 ")
 	}
 }
-
-func (s *Spotify) Init(props properties.Properties, env runtime.Environment) {
-	s.props = props
-	s.env = env
-}
