@@ -4,7 +4,6 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 )
@@ -15,17 +14,12 @@ const (
 )
 
 type Status struct {
-	props properties.Properties
-	env   platform.Environment
-
-	String string
-	Error  bool
-	Code   int
+	base
 
 	template *template.Text
-
-	// Deprecated: Use {{ reason .Code }} instead
-	Meaning string
+	String   string
+	Meaning  string
+	Error    bool
 }
 
 func (s *Status) Template() string {
@@ -46,24 +40,17 @@ func (s *Status) Enabled() bool {
 	return s.Error
 }
 
-func (s *Status) Init(props properties.Properties, env platform.Environment) {
-	s.props = props
-	s.env = env
-
+func (s *Status) formatStatus(status int, pipeStatus string) string {
 	statusTemplate := s.props.GetString(StatusTemplate, "{{ .Code }}")
 	s.template = &template.Text{
 		Template: statusTemplate,
-		Env:      s.env,
 	}
-}
 
-func (s *Status) formatStatus(status int, pipeStatus string) string {
 	if status != 0 {
 		s.Error = true
 	}
 
 	if len(pipeStatus) == 0 {
-		s.Code = status
 		s.template.Context = s
 		if text, err := s.template.Render(); err == nil {
 			return text
@@ -75,6 +62,13 @@ func (s *Status) formatStatus(status int, pipeStatus string) string {
 
 	var builder strings.Builder
 
+	// use an anaonymous struct to avoid
+	// confusion with the template context
+	// that already has a .Code global property
+	var context struct {
+		Code int
+	}
+
 	splitted := strings.Split(pipeStatus, " ")
 	for i, codeStr := range splitted {
 		write := func(text string) {
@@ -94,8 +88,9 @@ func (s *Status) formatStatus(status int, pipeStatus string) string {
 			s.Error = true
 		}
 
-		s.Code = code
-		s.template.Context = s
+		context.Code = code
+
+		s.template.Context = context
 		text, err := s.template.Render()
 		if err != nil {
 			write(codeStr)
